@@ -1,5 +1,6 @@
 #![warn(clippy::pedantic)]
 #![warn(clippy::nursery)]
+// #![warn(rust_2018_idioms)]
 #![forbid(unsafe_code)]
 // #![warn(clippy::restriction)]
 /**
@@ -40,8 +41,6 @@ use config::Termusic;
 use std::path::Path;
 use std::process;
 
-extern crate tuirealm;
-
 use ui::{UI, VERSION};
 
 fn main() {
