@@ -34,15 +34,9 @@ use regex::Regex;
 use std::convert::From;
 use tui_realm_stdlib::{Label, Select};
 use tuirealm::command::{Cmd, CmdResult, Direction};
-use tuirealm::event::{Key, KeyEvent, KeyModifiers};
+use tuirealm::event::{Key, KeyEvent, KeyModifiers, NoUserEvent};
 use tuirealm::props::{Alignment, BorderType, Borders, Color, Style, TextModifiers};
-use tuirealm::{
-    AttrValue, Attribute, Component, Event, MockComponent, NoUserEvent, State, StateValue,
-};
-// use lazy_static::lazy_static;
-// lazy_static!{
-//     static ref COLOR_LIST: [&str] = ["abc"];
-// }
+use tuirealm::{AttrValue, Attribute, Component, Event, MockComponent, State, StateValue};
 lazy_static! {
 
     /**
@@ -81,6 +75,8 @@ pub struct CESelectColor {
     component: Select,
     id: IdColorEditor,
     style_color_symbol: StyleColorSymbol,
+    on_key_shift: Msg,
+    on_key_backshift: Msg,
 }
 
 impl CESelectColor {
@@ -89,6 +85,8 @@ impl CESelectColor {
         id: IdColorEditor,
         color: Color,
         style_color_symbol: &StyleColorSymbol,
+        on_key_shift: Msg,
+        on_key_backshift: Msg,
     ) -> Self {
         let init_value = Self::init_color_select(&id, style_color_symbol);
         let mut choices = vec![];
@@ -112,6 +110,8 @@ impl CESelectColor {
                 .value(init_value),
             id,
             style_color_symbol: style_color_symbol.clone(),
+            on_key_shift,
+            on_key_backshift,
         }
     }
 
@@ -178,52 +178,13 @@ impl CESelectColor {
 impl Component<Msg, NoUserEvent> for CESelectColor {
     fn on(&mut self, ev: Event<NoUserEvent>) -> Option<Msg> {
         let cmd_result = match ev {
-            Event::Keyboard(KeyEvent { code: Key::Tab, .. }) => match self.id {
-                IdColorEditor::LibraryForeground => {
-                    return Some(Msg::ColorEditor(CEMsg::LibraryForegroundBlur));
-                }
-                IdColorEditor::LibraryBackground => {
-                    return Some(Msg::ColorEditor(CEMsg::LibraryBackgroundBlur));
-                }
-                IdColorEditor::LibraryBorder => {
-                    return Some(Msg::ColorEditor(CEMsg::LibraryBorderBlur));
-                }
-                IdColorEditor::LibraryHighlight => {
-                    return Some(Msg::ColorEditor(CEMsg::LibraryHighlightBlur));
-                }
-                IdColorEditor::PlaylistForeground => {
-                    return Some(Msg::ColorEditor(CEMsg::PlaylistForegroundBlur));
-                }
-                IdColorEditor::PlaylistBackground => {
-                    return Some(Msg::ColorEditor(CEMsg::PlaylistBackgroundBlur));
-                }
-                IdColorEditor::PlaylistBorder => {
-                    return Some(Msg::ColorEditor(CEMsg::PlaylistBorderBlur));
-                }
-                IdColorEditor::PlaylistHighlight => {
-                    return Some(Msg::ColorEditor(CEMsg::PlaylistHighlightBlur));
-                }
-                IdColorEditor::ProgressForeground => {
-                    return Some(Msg::ColorEditor(CEMsg::ProgressForegroundBlur));
-                }
-                IdColorEditor::ProgressBackground => {
-                    return Some(Msg::ColorEditor(CEMsg::ProgressBackgroundBlur));
-                }
-                IdColorEditor::ProgressBorder => {
-                    return Some(Msg::ColorEditor(CEMsg::ProgressBorderBlur));
-                }
-                IdColorEditor::LyricForeground => {
-                    return Some(Msg::ColorEditor(CEMsg::LyricForegroundBlur));
-                }
-                IdColorEditor::LyricBackground => {
-                    return Some(Msg::ColorEditor(CEMsg::LyricBackgroundBlur));
-                }
-                IdColorEditor::LyricBorder => {
-                    return Some(Msg::ColorEditor(CEMsg::LyricBorderBlur));
-                }
-
-                _ => CmdResult::None,
-            },
+            Event::Keyboard(KeyEvent { code: Key::Tab, .. }) => {
+                return Some(self.on_key_shift.clone())
+            }
+            Event::Keyboard(KeyEvent {
+                code: Key::BackTab,
+                modifiers: KeyModifiers::SHIFT,
+            }) => return Some(self.on_key_backshift.clone()),
             Event::Keyboard(KeyEvent {
                 code: Key::Esc | Key::Char('q'),
                 ..
@@ -292,6 +253,8 @@ impl CELibraryForeground {
                     .library_foreground()
                     .unwrap_or(Color::Blue),
                 style_color_symbol,
+                Msg::ColorEditor(CEMsg::LibraryForegroundBlurDown),
+                Msg::ColorEditor(CEMsg::LibraryForegroundBlurUp),
             ),
         }
     }
@@ -318,6 +281,8 @@ impl CELibraryBackground {
                     .library_background()
                     .unwrap_or(Color::Blue),
                 style_color_symbol,
+                Msg::ColorEditor(CEMsg::LibraryBackgroundBlurDown),
+                Msg::ColorEditor(CEMsg::LibraryBackgroundBlurUp),
             ),
         }
     }
@@ -342,6 +307,8 @@ impl CELibraryBorder {
                 IdColorEditor::LibraryBorder,
                 style_color_symbol.library_border().unwrap_or(Color::Blue),
                 style_color_symbol,
+                Msg::ColorEditor(CEMsg::LibraryBorderBlurDown),
+                Msg::ColorEditor(CEMsg::LibraryBorderBlurUp),
             ),
         }
     }
@@ -368,6 +335,8 @@ impl CELibraryHighlight {
                     .library_highlight()
                     .unwrap_or(Color::Blue),
                 style_color_symbol,
+                Msg::ColorEditor(CEMsg::LibraryHighlightBlurDown),
+                Msg::ColorEditor(CEMsg::LibraryHighlightBlurUp),
             ),
         }
     }
@@ -415,6 +384,8 @@ impl CEPlaylistForeground {
                     .playlist_foreground()
                     .unwrap_or(Color::Blue),
                 style_color_symbol,
+                Msg::ColorEditor(CEMsg::PlaylistForegroundBlurDown),
+                Msg::ColorEditor(CEMsg::PlaylistForegroundBlurUp),
             ),
         }
     }
@@ -441,6 +412,8 @@ impl CEPlaylistBackground {
                     .playlist_background()
                     .unwrap_or(Color::Blue),
                 style_color_symbol,
+                Msg::ColorEditor(CEMsg::PlaylistBackgroundBlurDown),
+                Msg::ColorEditor(CEMsg::PlaylistBackgroundBlurUp),
             ),
         }
     }
@@ -465,6 +438,8 @@ impl CEPlaylistBorder {
                 IdColorEditor::PlaylistBorder,
                 style_color_symbol.playlist_border().unwrap_or(Color::Blue),
                 style_color_symbol,
+                Msg::ColorEditor(CEMsg::PlaylistBorderBlurDown),
+                Msg::ColorEditor(CEMsg::PlaylistBorderBlurUp),
             ),
         }
     }
@@ -491,6 +466,8 @@ impl CEPlaylistHighlight {
                     .playlist_highlight()
                     .unwrap_or(Color::Blue),
                 style_color_symbol,
+                Msg::ColorEditor(CEMsg::PlaylistHighlightBlurDown),
+                Msg::ColorEditor(CEMsg::PlaylistHighlightBlurUp),
             ),
         }
     }
@@ -538,6 +515,8 @@ impl CEProgressForeground {
                     .progress_foreground()
                     .unwrap_or(Color::Blue),
                 style_color_symbol,
+                Msg::ColorEditor(CEMsg::ProgressForegroundBlurDown),
+                Msg::ColorEditor(CEMsg::ProgressForegroundBlurUp),
             ),
         }
     }
@@ -564,6 +543,8 @@ impl CEProgressBackground {
                     .progress_background()
                     .unwrap_or(Color::Blue),
                 style_color_symbol,
+                Msg::ColorEditor(CEMsg::ProgressBackgroundBlurDown),
+                Msg::ColorEditor(CEMsg::ProgressBackgroundBlurUp),
             ),
         }
     }
@@ -588,6 +569,8 @@ impl CEProgressBorder {
                 IdColorEditor::ProgressBorder,
                 style_color_symbol.progress_border().unwrap_or(Color::Blue),
                 style_color_symbol,
+                Msg::ColorEditor(CEMsg::ProgressBorderBlurDown),
+                Msg::ColorEditor(CEMsg::ProgressBorderBlurUp),
             ),
         }
     }
@@ -633,6 +616,8 @@ impl CELyricForeground {
                 IdColorEditor::LyricForeground,
                 style_color_symbol.lyric_foreground().unwrap_or(Color::Blue),
                 style_color_symbol,
+                Msg::ColorEditor(CEMsg::LyricForegroundBlurDown),
+                Msg::ColorEditor(CEMsg::LyricForegroundBlurUp),
             ),
         }
     }
@@ -657,6 +642,8 @@ impl CELyricBackground {
                 IdColorEditor::LyricBackground,
                 style_color_symbol.lyric_background().unwrap_or(Color::Blue),
                 style_color_symbol,
+                Msg::ColorEditor(CEMsg::LyricBackgroundBlurDown),
+                Msg::ColorEditor(CEMsg::LyricBackgroundBlurUp),
             ),
         }
     }
@@ -681,6 +668,8 @@ impl CELyricBorder {
                 IdColorEditor::LyricBorder,
                 style_color_symbol.lyric_border().unwrap_or(Color::Blue),
                 style_color_symbol,
+                Msg::ColorEditor(CEMsg::LyricBorderBlurDown),
+                Msg::ColorEditor(CEMsg::LyricBorderBlurUp),
             ),
         }
     }
