@@ -84,6 +84,7 @@ pub struct Model {
     pub current_song: Option<Song>,
     pub tageditor_song: Option<Song>,
     pub time_pos: i64,
+    pub time_pos_elapsed: std::time::Instant,
     pub lyric_line: String,
     youtube_options: YoutubeOptions,
     pub sender: Sender<UpdateComponents>,
@@ -135,6 +136,7 @@ impl Model {
             current_song: None,
             tageditor_song: None,
             time_pos: 0,
+            time_pos_elapsed: std::time::Instant::now(),
             lyric_line: String::new(),
             youtube_options: YoutubeOptions::new(),
             sender: tx,
